@@ -1,30 +1,22 @@
 #include "charball.h"
 
 #include <QRandomGenerator>
-#include <cmath>
 
-CharBall::CharBall(int size, int position, int speed, QChar character)
-    : color(QRandomGenerator::global()->bounded(128, 256),
-        QRandomGenerator::global()->bounded(128, 256),
-        QRandomGenerator::global()->bounded(128, 256))
+CharBall::CharBall(int size, int position, QChar character)
+    : currentRadius(size / 2)
+    , destroyed(0)
+    , color(QRandomGenerator::global()->bounded(128, 256),
+          QRandomGenerator::global()->bounded(128, 256),
+          QRandomGenerator::global()->bounded(128, 256))
+    , currentCharacter(character)
 {
-    currentSpeed = speed;
-    currentRadius = size / 2;
-    currentY = -2 - size;
-    currentX = position;
-    currentCharacter = character;
-    setPos(currentX, currentY);
-
-    destroyed = 0;
-    // startTimer(1000 / 33);
+    setPos(position, -2 - size);
 }
 
 QRectF CharBall::boundingRect() const
 {
-
-    qreal adjust = 0.0;
-    return QRectF(-currentRadius - adjust, -currentRadius - adjust,
-        (2 * currentRadius) + adjust, (2 * currentRadius) + adjust);
+    return QRectF(-currentRadius, -currentRadius, (2 * currentRadius),
+        (2 * currentRadius));
 }
 
 QPainterPath CharBall::shape() const
@@ -39,12 +31,10 @@ QPainterPath CharBall::shape() const
 void CharBall::paint(
     QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-
     // Body
     painter->setBrush(color);
     painter->drawEllipse(
         -currentRadius, -currentRadius, 2 * currentRadius, 2 * currentRadius);
-    // painter->setBrush(QColor(0, 0, 0));
 
     if (destroyed != 0) {
         destroying();
@@ -56,8 +46,7 @@ QChar CharBall::character() { return currentCharacter; }
 void CharBall::destroy()
 {
     destroyed = 56;
-    // delete this;
-    // return;
+
     update();
 }
 
@@ -65,7 +54,7 @@ void CharBall::destroying()
 {
     color = QColor(0, 0, 0);
     destroyed--;
-    // currentRadius = currentRadius - (28 + (destroyed / 4));
+
     if (destroyed < 2) {
         destroyed = 0;
         this->setVisible(false); // delete this;
