@@ -16,7 +16,7 @@ class CharBall : public QObject, public QGraphicsItem {
     Q_INTERFACES(QGraphicsItem)
 
 public:
-    CharBall(int size, int position, int speed, QChar character);
+    CharBall(int size, int position, QChar character);
 
     QRectF boundingRect() const;
     QPainterPath shape() const;
@@ -30,10 +30,7 @@ public:
 private:
     void destroying();
 
-    int currentSpeed;
-    int currentX;
-    int currentY;
-    int currentRadius;
+    const int currentRadius;
     int destroyed;
     QColor color;
     QChar currentCharacter;
