@@ -35,7 +35,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include <QSqlQuery>
 #include <QVariant>
 
-#include "def/defines.h"
 #include "startsql.h"
 
 // Konstruktor
@@ -426,8 +425,6 @@ bool StartSql::analyzeLessons(QString lessonType)
     QSqlQuery subQuery;
     QHash<int, int> unicodeErrorHash;
     QHash<int, int> unicodeErrorHashClean;
-    int errorNum = 0;
-    int rowsRead = 0;
 
     if (!mainQuery.exec("SELECT char_unicode FROM lesson_chars;")) {
         // Error message
@@ -436,7 +433,6 @@ bool StartSql::analyzeLessons(QString lessonType)
 
     while (mainQuery.next()) {
         unicodeErrorHashClean[mainQuery.value(0).toInt()] = 0;
-        errorNum++;
     }
 
     // 1. Delete current lessonanalysis table
@@ -517,7 +513,6 @@ bool StartSql::analyzeLessons(QString lessonType)
         if (!subQuery.exec(queryString)) {
             return false;
         }
-        rowsRead++;
     }
 
     return true;
