@@ -37,14 +37,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
 // Konstruktor
 TrainingSql::TrainingSql(QString replace, QString regexp, QString layout)
+    : queryCounter(0)
+    , replaceSetting(replace)
+    , regexpSetting(regexp)
 {
-    setSynchron(SYNCHRON_DB_WHILE_TRAINING);
-    queryCounter = 0;
-    replaceSetting = replace;
+    setSynchron(t10::synchron_db_while_training);
     if (replaceSetting == "NULL") {
         replaceSetting = getKeyboardLayoutReplaceRoutine(layout);
     }
-    regexpSetting = regexp;
+
     if (regexpSetting == "NULL") {
         regexpSetting = getKeyboardLayoutRegexpRoutine(layout);
     }
@@ -198,8 +199,9 @@ QString TrainingSql::createLesson(int lesson, int type, int unit,
             textOutputSub = query.value(1).toString();
             counterToNewLine += textOutputSub.length();
             if (unit == 0
-                || (unit == 1 && counterToNewLine > NUM_TOKEN_UNTIL_NEW_LINE)) {
-                textOutputSub.append(QChar(TOKEN_NEW_LINE));
+                || (unit == 1
+                    && counterToNewLine > t10::num_token_until_new_line)) {
+                textOutputSub.append(t10::token_new_line);
                 counterToNewLine = 0;
             } else {
                 textOutputSub.append(" ");
@@ -273,20 +275,20 @@ QString TrainingSql::updateLesson(
         sqlString = "SELECT " + tableName + ".content_id, " + tableName
             + ".content_text FROM " + tableName;
 
-        if (errorsExist && (queryCounter % NUM_INTELLIGENT_QUERYS) != 0) {
+        if (errorsExist && (queryCounter % t10::num_intelligent_queries) != 0) {
             // User error exists
             // -> create lesson SQL string sorted by errorUnicodeMax
             sqlString.append(" LEFT JOIN " + analysisName + " ON " + tableName
                 + ".content_id = " + analysisName + ".analysis_content AND ");
-            if ((lesson % 100) != LAST_LESSON || type != 0) {
+            if ((lesson % 100) != t10::last_lession || type != 0) {
                 sqlString.append(
                     tableName + ".content_lesson = " + QString::number(lesson));
             } else {
                 // Last training lesson over all previous lessons
                 sqlString.append("(" + tableName + ".content_lesson % 100) >= "
-                    + QString::number(BORDER_LESSON_IS_SENTENCE) + " AND ("
+                    + QString::number(t10::border_lesson_is_sentence) + " AND ("
                     + tableName + ".content_lesson % 100) <= "
-                    + QString::number(LAST_LESSON));
+                    + QString::number(t10::last_lession));
             }
             sqlString.append(" AND (" + tableName
                 + ".content_id % 1000) != 1 "
@@ -314,16 +316,16 @@ QString TrainingSql::updateLesson(
             // -> create standard lesson SQL string sorted by id
             sqlString.append(" WHERE");
             sqlString.append(" (" + tableName + ".content_id % 1000) != 0");
-            if ((lesson % 100) != LAST_LESSON || type != 0) {
+            if ((lesson % 100) != t10::last_lession || type != 0) {
                 sqlString.append(" AND " + tableName
                     + ".content_lesson = " + QString::number(lesson));
             } else {
                 // Last training lesson over all previous lessons
                 sqlString.append(" AND (" + tableName
                     + ".content_lesson % 100) >= "
-                    + QString::number(BORDER_LESSON_IS_SENTENCE) + " AND ("
+                    + QString::number(t10::border_lesson_is_sentence) + " AND ("
                     + tableName + ".content_lesson % 100) <= "
-                    + QString::number(LAST_LESSON));
+                    + QString::number(t10::last_lession));
             }
             sqlString.append(" ORDER BY Random();");
         }
@@ -337,7 +339,7 @@ QString TrainingSql::updateLesson(
                     // -> append to lessonsDoneList
                     lessonsDoneList.prepend(query.value(0).toInt());
                     // Check if lessonsDoneList exceeds its maximum
-                    if (lessonsDoneList.size() > NUM_TEXT_UNTIL_REPEAT) {
+                    if (lessonsDoneList.size() > t10::num_text_until_repeat) {
                         // lessonsDoneList exceeded -> remove last item
                         lessonsDoneList.removeLast();
                     }
@@ -370,7 +372,7 @@ QString TrainingSql::updateLesson(
     }
     while (query.next()) {
         textOutputSub = query.value(1).toString();
-        textOutputSub.append(QChar(TOKEN_NEW_LINE));
+        textOutputSub.append(t10::token_new_line);
 
         textOutput.append(
             replaceRoutine(textOutputSub, useEszett, useUmlaut, lesson, type));
@@ -391,7 +393,7 @@ QVariant TrainingSql::saveLesson(int lesson, int timelen, int tokenlen,
             + QString::number(errornum) + ", '"
             + timestamp.toString("yyyyMMddhhmmss") + "', "
             + QString::number(type) + ", '" + lessonName + "');")) {
-        return QVariant::Invalid;
+        return QVariant();
     }
     lastRowId = query.lastInsertId();
     return lastRowId;
@@ -403,7 +405,7 @@ QString TrainingSql::replaceRoutine(QString content,
 {
 
     // Tab char (an arrow)
-    content.replace(QChar(0x9), QChar(TOKEN_TAB), Qt::CaseSensitive);
+    content.replace(QChar(0x9), t10::token_tab, Qt::CaseSensitive);
 
     // Eszett
     /*if (!useEszett) {
@@ -421,12 +423,12 @@ QString TrainingSql::replaceRoutine(QString content,
                 content.replace(QChar(0x00dc), "Ue", Qt::CaseSensitive);
                 content.replace(QChar(0x20ac), "Eur", Qt::CaseSensitive);
                 content.replace(QChar(0x00a7), "Par.", Qt::CaseSensitive);
-        if ((lesson % 100) > LAST_LESSON && type == 0) {
+        if ((lesson % 100) > t10::last_lession && type == 0) {
                         content.replace(QChar(0x002c), ".", Qt::CaseSensitive);
                 }
     }*/
     if (!useUmlaut) {
-        if ((lesson % 100) > LAST_LESSON && type == 0) {
+        if ((lesson % 100) > t10::last_lession && type == 0) {
             content.replace(QChar(0x002c), ".", Qt::CaseSensitive);
         }
     }
@@ -443,8 +445,8 @@ QString TrainingSql::replaceRoutine(QString content,
         }
     }
     if (regexpSetting.left(2) == "[^") {
-        regexpSetting = regexpSetting.left(2) + QChar(TOKEN_NEW_LINE)
-            + QChar(TOKEN_TAB) + regexpSetting.mid(2);
+        regexpSetting = regexpSetting.left(2) + t10::token_new_line
+            + t10::token_tab + regexpSetting.mid(2);
         content.replace(QRegularExpression(regexpSetting), "");
     }
     return content;
