@@ -56,11 +56,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 LessonResult::LessonResult(
     int row, QList<QChar> charlist, QList<int> mistakelist, QWidget* parent)
     : QWidget(parent)
+    , charList(charlist)
+    , mistakeList(mistakelist)
+    , lessonRow(row)
 {
-    mistakeList = mistakelist;
-    charList = charlist;
-    lessonRow = row;
-
     // Create print push button
     buttonPrintLesson = new QPushButton(tr("Print"));
     buttonPrintLesson->setFixedHeight(20);
@@ -85,12 +84,13 @@ void LessonResult::readData()
     if (settings.value("radio_time", true).toBool()) {
         // Time limit selected
         settingsDuration = tr("%n minute(s)", "",
-            settings.value("spin_time", LESSON_TIMELEN_STANDARD).toInt());
+            settings.value("spin_time", t10::lesson_timelen_standard).toInt());
     } else {
         if (settings.value("radio_token", true).toBool()) {
             // Token limit selected
             settingsDuration = tr("%n character(s)", "",
-                settings.value("spin_token", LESSON_TOKENLEN_STANDARD).toInt());
+                settings.value("spin_token", t10::lesson_tokenlen_standard)
+                    .toInt());
         } else {
             // Lesson limit selected
             settingsDuration = tr("Entire Lesson");
@@ -244,16 +244,16 @@ void LessonResult::createOutput()
     p_no_mistake.setFontPointSize(9);
 #endif
 
-    h1.setFontFamilies({ "Arial" });
-    h2.setFontFamilies({ "Arial" });
-    h3.setFontFamilies({ "Arial" });
+    h1.setFontFamilies({"Arial"});
+    h2.setFontFamilies({"Arial"});
+    h3.setFontFamilies({"Arial"});
     h3.setFontWeight(QFont::Bold);
-    p.setFontFamilies({ "Arial" });
-    p_mistake.setFontFamilies({ "Arial" });
+    p.setFontFamilies({"Arial"});
+    p_mistake.setFontFamilies({"Arial"});
     p_mistake.setFontUnderline(true);
     p_mistake.setForeground(QBrush(QColor(255, 0, 0)));
     p_mistake.setFontWeight(QFont::Bold);
-    p_no_mistake.setFontFamilies({ "Arial" });
+    p_no_mistake.setFontFamilies({"Arial"});
 
     cursor.setPosition(topFrame->firstPosition());
 
@@ -393,8 +393,8 @@ void LessonResult::createOutput()
     // Pass layout to parent widget (this)
     this->setLayout(mainLayout);
 
-    connect(
-        buttonPrintLesson, SIGNAL(clicked()), this, SLOT(createPrintOutput()));
+    connect(buttonPrintLesson, &QPushButton::clicked, this,
+        &LessonResult::createPrintOutput);
 }
 
 void LessonResult::createPrintOutput()
@@ -427,22 +427,22 @@ void LessonResult::createPrintOutput()
     QTextCharFormat p_no_mistake;
 
     h1.setFontPointSize(20);
-    h1.setFontFamilies({ "Arial" });
+    h1.setFontFamilies({"Arial"});
     h2.setFontPointSize(15);
-    h2.setFontFamilies({ "Arial" });
+    h2.setFontFamilies({"Arial"});
     h2.setFontWeight(QFont::Bold);
     h3.setFontPointSize(11);
-    h3.setFontFamilies({ "Arial" });
+    h3.setFontFamilies({"Arial"});
     h3.setFontWeight(QFont::Bold);
     p.setFontPointSize(11);
-    p.setFontFamilies({ "Arial" });
+    p.setFontFamilies({"Arial"});
     p_mistake.setFontPointSize(11);
-    p_mistake.setFontFamilies({ "Arial" });
+    p_mistake.setFontFamilies({"Arial"});
     p_mistake.setFontUnderline(true);
     p_mistake.setForeground(QBrush(QColor(255, 0, 0)));
     p_mistake.setFontWeight(QFont::Bold);
     p_no_mistake.setFontPointSize(11);
-    p_no_mistake.setFontFamilies({ "Arial" });
+    p_no_mistake.setFontFamilies({"Arial"});
 
     cursor.setPosition(topFrame->firstPosition());
 
