@@ -39,26 +39,27 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
 ProgressionWidget::ProgressionWidget(QWidget* parent)
     : QWidget(parent)
+    , comboFilter(new QComboBox())
+    , comboOrder(new QComboBox())
+    , whereClausel("")
+    , orderClausel("ORDER BY user_lesson_timestamp")
+    , xAxisColumn(1)
+    , lessonSelected(-1)
 {
     // Fix the size of this class because of using fix sized images
     // setFixedSize(600, 310);
-    whereClausel = "";
-    orderClausel = "ORDER BY user_lesson_timestamp";
 
     xAxis = tr("Time");
-    xAxisColumn = 1;
-
-    lessonSelected = -1;
 
     // Create filter headline
     labelFilter = new QLabel(tr("Show: "));
-    comboFilter = new QComboBox();
+
     comboFilter->insertItem(0, tr("All Lessons"));
     comboFilter->insertItem(1, tr("Training Lessons"));
     comboFilter->insertItem(2, tr("Open Lessons"));
     comboFilter->insertItem(3, tr("Own Lessons"));
     labelOrder = new QLabel(tr("Order by x-axis:"));
-    comboOrder = new QComboBox();
+
     comboOrder->insertItem(0, tr("Time"));
     comboOrder->insertItem(1, tr("Lesson"));
     // comboOrder->insertItem(2, tr("Cpm"));
@@ -78,8 +79,10 @@ ProgressionWidget::ProgressionWidget(QWidget* parent)
     // Pass layout to parent widget (this)
     this->setLayout(mainLayout);
 
-    connect(comboFilter, SIGNAL(activated(int)), this, SLOT(changeFilter(int)));
-    connect(comboOrder, SIGNAL(activated(int)), this, SLOT(changeOrder(int)));
+    connect(comboFilter, &QComboBox::activated, this,
+        &ProgressionWidget::changeFilter);
+    connect(comboOrder, &QComboBox::activated, this,
+        &ProgressionWidget::changeOrder);
     getChartValues();
     setMouseTracking(true);
 }
@@ -182,13 +185,11 @@ void ProgressionWidget::paintEvent([[maybe_unused]] QPaintEvent* event)
 void ProgressionWidget::mouseMoveEvent(QMouseEvent* event)
 {
     lessonSelected = -1;
-
+    double pos_x = static_cast<double>(event->pos().x());
+    double pos_y = static_cast<double>(event->pos().y());
     for (int x = 0; x < lessonCounter; x++) {
-        if ((double)event->pos().x() > lessonsX[x] - 6.0
-            && (double)event->pos().x() < lessonsX[x] + 6.0
-            && (double)event->pos().y() > lessonsY[x] - 6.0
-            && (double)event->pos().y() < lessonsY[x] + 6.0) {
-
+        if (lessonsX[x] - 6.0 < pos_x && pos_x < lessonsX[x] + 6.0
+            && lessonsY[x] - 6.0 < pos_y && pos_y < lessonsY[x] + 6.0) {
             lessonSelected = x;
         }
     }
@@ -201,12 +202,12 @@ void ProgressionWidget::drawTooltip(
 {
 
     double yOffset = -66.0;
-    if (y < ((double)this->height() * (2.0 / 5.0))) {
+    if (y < (static_cast<double>(this->height()) * (2.0 / 5.0))) {
         yOffset = 6.0;
     }
 
     painter->setRenderHint(QPainter::Antialiasing, false);
-    painter->setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+    painter->setFont(QFont(t10::font_standard, t10::font_size_progress));
     painter->setPen(QColor(0, 0, 0));
 
     painter->setBrush(QColor(255, 255, 255));
@@ -223,68 +224,60 @@ void ProgressionWidget::drawGrid()
     painter.setRenderHint(QPainter::Antialiasing, false);
     double widgetLeft = 20.0;
     double widgetTop = 40.0;
-    double widgetWidth = (double)this->width() - 20.0;
-    double widgetHeight = (double)this->height();
-    int lessonCounterTemp = (lessonCounter > 1) ? lessonCounter : 2;
-    double xUnit = (widgetWidth - 120.0) / ((double)(lessonCounterTemp - 1));
-    double yUnit = (widgetHeight - 110.0) / (double)lessonGradeMax; // 120;
+    double widgetWidth = static_cast<double>(this->width()) - 20.0;
+    double widgetHeight = static_cast<double>(this->height());
+    double yUnit = (widgetHeight - 110.0) / static_cast<double>(lessonGradeMax);
+    double gridHeight = widgetHeight - 110.0;
+    double gridLength = widgetWidth - 120.0;
+
     QPen penDashLine;
 
-    painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+    painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
     painter.setPen(QColor(0, 0, 0));
 
     // Text y axis
-    painter.drawText(QRectF(widgetLeft,
-                         (widgetTop + widgetHeight - 113.0
-                             - ((double)lessonGradeMax * yUnit)),
-                         50.0, 10.0),
+    painter.drawText(
+        QRectF(widgetLeft, (widgetTop + widgetHeight - 113.0 - gridHeight),
+            50.0, 10.0),
         Qt::AlignCenter | Qt::AlignVCenter, tr("Points"));
     // Text x axis
-    painter.drawText(
-        QRectF((widgetLeft + 60.0 + ((double)(lessonCounterTemp - 1) * xUnit)),
-            (widgetTop + widgetHeight - 91.0), 60.0, 20.0),
+    painter.drawText(QRectF((widgetLeft + 60.0 + gridLength),
+                         (widgetTop + widgetHeight - 91.0), 60.0, 20.0),
         Qt::AlignLeft | Qt::AlignVCenter, xAxis);
     // y axis
-    painter.drawLine(QLineF(widgetLeft + 30.0,
-        widgetTop + widgetHeight - 95.0 - (lessonGradeMax * yUnit),
-        widgetLeft + 30.0, widgetTop + widgetHeight - 80.0));
+    painter.drawLine(
+        QLineF(widgetLeft + 30.0, widgetTop + widgetHeight - 95.0 - gridHeight,
+            widgetLeft + 30.0, widgetTop + widgetHeight - 80.0));
     // y axis arrow
-    painter.drawLine(QLineF(widgetLeft + 28.0,
-        widgetTop + widgetHeight - 93.0 - (lessonGradeMax * yUnit),
-        widgetLeft + 30.0,
-        widgetTop + widgetHeight - 95.0 - (lessonGradeMax * yUnit)));
-    painter.drawLine(QLineF(widgetLeft + 32.0,
-        widgetTop + widgetHeight - 93.0 - (lessonGradeMax * yUnit),
-        widgetLeft + 30.0,
-        widgetTop + widgetHeight - 95.0 - (lessonGradeMax * yUnit)));
+    painter.drawLine(
+        QLineF(widgetLeft + 28.0, widgetTop + widgetHeight - 93.0 - gridHeight,
+            widgetLeft + 30.0, widgetTop + widgetHeight - 95.0 - gridHeight));
+    painter.drawLine(
+        QLineF(widgetLeft + 32.0, widgetTop + widgetHeight - 93.0 - gridHeight,
+            widgetLeft + 30.0, widgetTop + widgetHeight - 95.0 - gridHeight));
     // x axis
     painter.drawLine(QLineF(widgetLeft + 28.0, widgetTop + widgetHeight - 80.0,
-        widgetLeft + 50.0 + ((double)(lessonCounterTemp - 1) * xUnit),
-        widgetTop + widgetHeight - 80.0));
+        widgetLeft + 50.0 + gridLength, widgetTop + widgetHeight - 80.0));
     // x axis arrow
     painter.drawLine(
-        QLineF(widgetLeft + 48.0 + ((double)(lessonCounterTemp - 1) * xUnit),
-            widgetTop + widgetHeight - 82.0,
-            widgetLeft + 50.0 + ((double)(lessonCounterTemp - 1) * xUnit),
-            widgetTop + widgetHeight - 80.0));
+        QLineF(widgetLeft + 48.0 + gridLength, widgetTop + widgetHeight - 82.0,
+            widgetLeft + 50.0 + gridLength, widgetTop + widgetHeight - 80.0));
     painter.drawLine(
-        QLineF(widgetLeft + 48.0 + ((double)(lessonCounterTemp - 1) * xUnit),
-            widgetTop + widgetHeight - 78.0,
-            widgetLeft + 50.0 + ((double)(lessonCounterTemp - 1) * xUnit),
-            widgetTop + widgetHeight - 80.0));
+        QLineF(widgetLeft + 48.0 + gridLength, widgetTop + widgetHeight - 78.0,
+            widgetLeft + 50.0 + gridLength, widgetTop + widgetHeight - 80.0));
     // Bottom unit line y axis
     painter.drawText(
         QRectF(widgetLeft + 4.0, widgetTop + widgetHeight - 85.0, 20.0, 10.0),
         Qt::AlignCenter | Qt::AlignVCenter, "0");
     // Unit lines and text y axis
     for (int x = 1; x <= (lessonGradeMax / 10); x++) {
+        double x10yUnit = static_cast<double>(x) * 10.0 * yUnit;
         painter.drawLine(QLineF(widgetLeft + 28.0,
-            widgetTop + widgetHeight - 80.0 - ((double)x * yUnit * 10.0),
-            widgetLeft + 50.0 + ((double)(lessonCounterTemp - 1) * xUnit),
-            widgetTop + widgetHeight - 80.0 - ((double)x * yUnit * 10.0)));
+            widgetTop + widgetHeight - 80.0 - x10yUnit,
+            widgetLeft + 50.0 + gridLength,
+            widgetTop + widgetHeight - 80.0 - x10yUnit));
         painter.drawText(
-            QRectF(widgetLeft + 4.0,
-                widgetTop + widgetHeight - 85.0 - ((double)x * yUnit * 10.0),
+            QRectF(widgetLeft + 4.0, widgetTop + widgetHeight - 85.0 - x10yUnit,
                 20.0, 10.0),
             Qt::AlignCenter | Qt::AlignVCenter, QString::number(x * 10));
     }
@@ -296,29 +289,24 @@ void ProgressionWidget::drawGrid()
             lessonsAxis[0]);
     }
     if (lessonCounter > 1) {
-        painter.drawText(
-            QRectF(widgetLeft - 20.0 + ((double)(lessonCounter - 1) * xUnit),
-                widgetTop + widgetHeight - 74.0, 120.0, 30.0),
+        painter.drawText(QRectF(widgetLeft - 20.0 + gridLength,
+                             widgetTop + widgetHeight - 74.0, 120.0, 30.0),
             Qt::AlignCenter | Qt::AlignVCenter | Qt::TextWordWrap,
             lessonsAxis[lessonCounter - 1]);
     }
+    double posY = widgetTop + widgetHeight - 80.0
+        - static_cast<double>(lessonAv) * yUnit;
     // Average
     penDashLine.setBrush(QColor(249, 126, 50));
     penDashLine.setStyle(Qt::DashLine);
     painter.setPen(penDashLine);
-    painter.drawLine(QLineF(widgetLeft + 28.0,
-        widgetTop + widgetHeight - 80.0 - ((double)lessonAv * yUnit),
-        widgetLeft + 50.0 + ((double)(lessonCounterTemp - 1) * xUnit),
-        widgetTop + widgetHeight - 80.0 - ((double)lessonAv * yUnit)));
+    painter.drawLine(
+        QLineF(widgetLeft + 28.0, posY, widgetLeft + 50.0 + gridLength, posY));
     penDashLine.setStyle(Qt::SolidLine);
     painter.setPen(penDashLine);
-    painter.drawEllipse(QRectF(widgetLeft - 10.0,
-        widgetTop + (widgetHeight - 80.0) - ((double)lessonAv * yUnit) - 3.0,
-        6.0, 6.0));
-    painter.drawLine(QLineF(widgetLeft - 5.0,
-        widgetTop + widgetHeight - 80.0 - ((double)lessonAv * yUnit) - 5.0,
-        widgetLeft - 10.0,
-        widgetTop + widgetHeight - 80.0 - ((double)lessonAv * yUnit) + 5.0));
+    painter.drawEllipse(QRectF(widgetLeft - 10.0, posY - 3.0, 6.0, 6.0));
+    painter.drawLine(
+        QLineF(widgetLeft - 5.0, posY - 5.0, widgetLeft - 10.0, posY + 5.0));
 }
 
 void ProgressionWidget::drawGraph()
@@ -335,10 +323,11 @@ void ProgressionWidget::drawGraph()
     double widgetWidth = this->width() - 20.0;
     double widgetHeight = this->height();
     int lessonCounterTemp = (lessonCounter > 1) ? lessonCounter : 2;
-    double xUnit = (widgetWidth - 120.0) / ((double)(lessonCounterTemp - 1));
-    double yUnit = (widgetHeight - 110.0) / (double)lessonGradeMax;
+    double xUnit
+        = (widgetWidth - 120.0) / static_cast<double>(lessonCounterTemp - 1);
+    double yUnit = (widgetHeight - 110.0) / static_cast<double>(lessonGradeMax);
 
-    painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+    painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
 
     penOrange.setStyle(Qt::SolidLine);
     penOrange.setBrush(QColor(249, 126, 50));
@@ -378,7 +367,7 @@ void ProgressionWidget::drawGraph()
         painter.setPen(penBlack);
         painter.drawEllipse(
             QRectF(widgetLeft + 60.0, widgetTop - 20.0, 4.0, 4.0));
-        painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+        painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
         painter.drawText(
             QRectF(widgetLeft + 70.0, widgetTop - 24.0, 90.0, 12.0),
             Qt::AlignLeft | Qt::AlignVCenter, tr("Training Lesson"));
@@ -386,14 +375,14 @@ void ProgressionWidget::drawGraph()
         painter.setPen(penBlue);
         painter.drawEllipse(
             QRectF(widgetLeft + 60.0, widgetTop - 5.0, 4.0, 4.0));
-        painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+        painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
         painter.drawText(QRectF(widgetLeft + 70.0, widgetTop - 9.0, 90.0, 12.0),
             Qt::AlignLeft | Qt::AlignVCenter, tr("Open Lesson"));
 
         painter.setPen(penGreen);
         painter.drawEllipse(
             QRectF(widgetLeft + 60.0, widgetTop + 10.0, 4.0, 4.0));
-        painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+        painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
         painter.drawText(QRectF(widgetLeft + 70.0, widgetTop + 6.0, 90.0, 12.0),
             Qt::AlignLeft | Qt::AlignVCenter, tr("Own Lesson"));
 #else
@@ -402,7 +391,7 @@ void ProgressionWidget::drawGraph()
         painter.setPen(penBlack);
         painter.drawEllipse(
             QRectF(widgetLeft + 70.0, widgetTop - 20.0, 4.0, 4.0));
-        painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+        painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
         painter.drawText(
             QRectF(widgetLeft + 80.0, widgetTop - 24.0, 90.0, 12.0),
             Qt::AlignLeft | Qt::AlignVCenter, tr("Training Lesson"));
@@ -410,14 +399,14 @@ void ProgressionWidget::drawGraph()
         painter.setPen(penBlue);
         painter.drawEllipse(
             QRectF(widgetLeft + 70.0, widgetTop - 5.0, 4.0, 4.0));
-        painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+        painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
         painter.drawText(QRectF(widgetLeft + 80.0, widgetTop - 9.0, 90.0, 12.0),
             Qt::AlignLeft | Qt::AlignVCenter, tr("Open Lesson"));
 
         painter.setPen(penGreen);
         painter.drawEllipse(
             QRectF(widgetLeft + 70.0, widgetTop + 10.0, 4.0, 4.0));
-        painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+        painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
         painter.drawText(QRectF(widgetLeft + 80.0, widgetTop + 6.0, 90.0, 12.0),
             Qt::AlignLeft | Qt::AlignVCenter, tr("Own Lesson"));
 #endif
@@ -426,18 +415,19 @@ void ProgressionWidget::drawGraph()
     // Number of lines
     for (int x = 0; x < lessonCounter; x++) {
         painter.setPen(penOrange);
-        auto currentValue = (double)lessonsGrades[x];
+        auto currentValue = static_cast<double>(lessonsGrades[x]);
         if (currentValue < 0) {
             currentValue = 0.0;
         }
+        double posX = widgetLeft + 40.0 + static_cast<double>(x) * xUnit;
         if (x < lessonCounter - 1) {
-            auto nextValue = (double)lessonsGrades[x + 1];
+            auto nextValue = static_cast<double>(lessonsGrades[x + 1]);
             if (nextValue < 0) {
                 nextValue = 0.0;
             }
-            painter.drawLine(QLineF(widgetLeft + 40.0 + ((double)x * xUnit),
+            painter.drawLine(QLineF(posX,
                 widgetTop + (widgetHeight - 80) - (currentValue * yUnit),
-                widgetLeft + 40.0 + ((double)(x + 1) * xUnit),
+                posX + xUnit,
                 widgetTop + (widgetHeight - 80.0) - (nextValue * yUnit)));
         }
         switch (lessonsType[x]) {
@@ -455,18 +445,16 @@ void ProgressionWidget::drawGraph()
         if (lessonSelected == x) {
             painter.setPen(penWhite);
         }
-        lessonsX[x] = widgetLeft + 40.0 + ((double)x * xUnit);
+        lessonsX[x] = posX;
         lessonsY[x]
             = widgetTop + (widgetHeight - 80.0) - (currentValue * yUnit);
         painter.drawEllipse(
             QRectF(lessonsX[x] - 2.0, lessonsY[x] - 2.0, 4.0, 4.0));
-        // painter.setPen(QColor(255, 255, 255));
-        // painter.drawLine(60 + (x * xUnit), widgetHeight - 80,
-        //	60 + (x * xUnit), (widgetHeight - 80) - (currentValue * yUnit));
         if (lessonsType[x] == 0) {
-            painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS_LESSON));
+            painter.setFont(
+                QFont(t10::font_standard, t10::font_size_progress_lesson));
             painter.drawText(
-                QRectF(widgetLeft + 30.0 + ((double)x * xUnit),
+                QRectF(posX - 10.0,
                     widgetTop + (widgetHeight - 96.0) - (currentValue * yUnit),
                     20.0, 10.0),
                 Qt::AlignCenter | Qt::AlignVCenter, lessonsNumbers[x]);
@@ -474,7 +462,6 @@ void ProgressionWidget::drawGraph()
     }
 
     if (lessonSelected != -1) {
-
         drawTooltip(&painter, lessonsX[lessonSelected],
             lessonsY[lessonSelected],
             lessonsNames[lessonSelected] + "\n"
@@ -491,7 +478,7 @@ void ProgressionWidget::drawNothing()
     int widgetWidth = this->width();
     int widgetHeight = this->height();
 
-    painter.setFont(QFont(FONT_STANDARD, FONT_SIZE_PROGRESS));
+    painter.setFont(QFont(t10::font_standard, t10::font_size_progress));
     painter.setPen(QColor(0, 0, 0));
     // Text y axis
     painter.drawText(QRectF(0.0, 0.0, widgetWidth, widgetHeight),
