@@ -41,19 +41,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include <QVBoxLayout>
 
 #include "def/defines.h"
-#include "def/errordefines.h"
 #include "errormessage.h"
-#include "illustrationdialog.h"
 #include "lessondialog.h"
 #include "sql/startsql.h"
 #include "startwidget.h"
 
 StartWidget::StartWidget(QWidget* parent)
     : QWidget(parent)
+    , companyLogo(new CompanyLogo(this))
 {
-    // Set the logo
-    companyLogo = new CompanyLogo(this);
-
     readLicenseSettings();
 
     // Create group boxes with user settings
@@ -469,43 +465,49 @@ bottomboxesLayoutV->addWidget(groupIntelligence);*/
 void StartWidget::createConnections()
 {
     // Widget connections
-    connect(buttonTraining, SIGNAL(clicked()), this, SLOT(clickTraining()));
-    connect(buttonHelp, SIGNAL(clicked()), this, SLOT(showHelp()));
-
-    connect(radioLimitTime, SIGNAL(clicked()), this, SLOT(toggleLimit()));
-    connect(radioLimitToken, SIGNAL(clicked()), this, SLOT(toggleLimit()));
-    connect(radioLimitLesson, SIGNAL(clicked()), this, SLOT(toggleLimit()));
-    connect(checkErrorStop, SIGNAL(clicked()), this, SLOT(toggleError()));
-    connect(checkHelpers, SIGNAL(clicked()), this, SLOT(toggleHelpers()));
-    connect(
-        checkIntelligence, SIGNAL(clicked()), this, SLOT(toggleIntelligence()));
-
-    connect(listLesson, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this,
-        SLOT(doubleClickLesson(QListWidgetItem*)));
-    connect(listOpen, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this,
-        SLOT(doubleClickLesson(QListWidgetItem*)));
-    connect(listOwn, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this,
-        SLOT(doubleClickLesson(QListWidgetItem*)));
-
-    connect(lessonNew, SIGNAL(triggered()), this, SLOT(clickNewLesson()));
-    connect(lessonImport, SIGNAL(triggered()), this, SLOT(clickImportLesson()));
-    connect(lessonExport, SIGNAL(triggered()), this, SLOT(clickExportLesson()));
-    connect(lessonDel, SIGNAL(triggered()), this, SLOT(clickDeleteLesson()));
-    connect(lessonEdit, SIGNAL(triggered()), this, SLOT(clickEditLesson()));
+    connect(buttonTraining, &QPushButton::clicked, this,
+        &StartWidget::clickTraining);
+    connect(buttonHelp, &QPushButton::clicked, this, &StartWidget::showHelp);
 
     connect(
-        tabLessons, SIGNAL(currentChanged(int)), this, SLOT(toggleTabs(int)));
-    connect(comboTheme, SIGNAL(activated(int)), this, SLOT(toggleThemes(int)));
+        radioLimitTime, &QPushButton::clicked, this, &StartWidget::toggleLimit);
+    connect(radioLimitToken, &QPushButton::clicked, this,
+        &StartWidget::toggleLimit);
+    connect(radioLimitLesson, &QPushButton::clicked, this,
+        &StartWidget::toggleLimit);
+    connect(
+        checkErrorStop, &QPushButton::clicked, this, &StartWidget::toggleError);
+    connect(
+        checkHelpers, &QPushButton::clicked, this, &StartWidget::toggleHelpers);
+    connect(checkIntelligence, &QPushButton::clicked, this,
+        &StartWidget::toggleIntelligence);
+
+    connect(listLesson, &QListWidget::itemDoubleClicked, this,
+        &StartWidget::doubleClickLesson);
+    connect(listOpen, &QListWidget::itemDoubleClicked, this,
+        &StartWidget::doubleClickLesson);
+    connect(listOwn, &QListWidget::itemDoubleClicked, this,
+        &StartWidget::doubleClickLesson);
+
+    connect(lessonNew, &QAction::triggered, this, &StartWidget::clickNewLesson);
+    connect(lessonImport, &QAction::triggered, this,
+        &StartWidget::clickImportLesson);
+    connect(lessonExport, &QAction::triggered, this,
+        &StartWidget::clickExportLesson);
+    connect(
+        lessonDel, &QAction::triggered, this, &StartWidget::clickDeleteLesson);
+    connect(
+        lessonEdit, &QAction::triggered, this, &StartWidget::clickEditLesson);
+
+    connect(tabLessons, &QTabWidget::currentChanged, this,
+        &StartWidget::toggleTabs);
+    connect(
+        comboTheme, &QComboBox::activated, this, &StartWidget::toggleThemes);
 }
 
 // TODO: this is definitly unused and should be removed
 void StartWidget::fillLessonList([[maybe_unused]] bool themeChanged = false)
 {
-    int trainingNum = 0;
-    int openNum = 0;
-    int ownNum = 0;
-    int themesNum = 0;
-
 #if APP_PORTABLE
     QSettings settings(
         QCoreApplication::applicationDirPath() + "/portable/settings.ini",
@@ -515,18 +517,18 @@ void StartWidget::fillLessonList([[maybe_unused]] bool themeChanged = false)
 #endif
     settings.beginGroup("main");
     QString languageLesson
-        = settings.value("language_lesson", APP_STD_LANGUAGE_LESSON).toString();
+        = settings.value("language_lesson", t10::app_std_language_lesson)
+              .toString();
     settings.endGroup();
 
     StartSql* lessonSql = new StartSql();
     // Training lesson list
     // --------------------
-    if ((trainingNum = lessonSql->fillLessonList(
-             listLesson, &arrayTraining, languageLesson))
+    if (lessonSql->fillLessonList(listLesson, &arrayTraining, languageLesson)
         == -1) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_EXIST,
+        errorMessage->showMessage(Error::lessons_exist,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -542,12 +544,12 @@ void StartWidget::fillLessonList([[maybe_unused]] bool themeChanged = false)
     settings.endGroup();
     // Open themes list
     // --------------------
-    if ((themesNum = lessonSql->fillThemes(
-             comboTheme, &arrayThemes, languageLesson, tr("All")))
+    if (lessonSql->fillThemes(
+            comboTheme, &arrayThemes, languageLesson, tr("All"))
         == -1) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_EXIST,
+        errorMessage->showMessage(Error::lessons_exist,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -571,12 +573,12 @@ void StartWidget::fillLessonList([[maybe_unused]] bool themeChanged = false)
     settings.endGroup();
     // Open lesson list
     // --------------------
-    if ((openNum = lessonSql->fillOpenList(listOpen, &arrayOpen,
-             arrayThemes.at(comboTheme->currentIndex()), languageLesson))
+    if (lessonSql->fillOpenList(listOpen, &arrayOpen,
+            arrayThemes.at(comboTheme->currentIndex()), languageLesson)
         == -1) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_EXIST,
+        errorMessage->showMessage(Error::lessons_exist,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -592,10 +594,10 @@ void StartWidget::fillLessonList([[maybe_unused]] bool themeChanged = false)
     settings.endGroup();
     // Own lesson list
     // --------------------
-    if ((ownNum = lessonSql->fillOwnList(listOwn, &arrayOwn)) == -1) {
+    if (lessonSql->fillOwnList(listOwn, &arrayOwn) == -1) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_EXIST,
+        errorMessage->showMessage(Error::lessons_exist,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -718,7 +720,8 @@ void StartWidget::toggleThemes(int index)
 #endif
     settings.beginGroup("main");
     QString languageLesson
-        = settings.value("language_lesson", APP_STD_LANGUAGE_LESSON).toString();
+        = settings.value("language_lesson", t10::app_std_language_lesson)
+              .toString();
     settings.endGroup();
     StartSql* lessonSql = new StartSql();
     // Open lesson list
@@ -728,7 +731,7 @@ void StartWidget::toggleThemes(int index)
         == -1) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_EXIST,
+        errorMessage->showMessage(Error::lessons_exist,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -787,11 +790,11 @@ void StartWidget::toggleTabs(int index)
         }
         settings.beginGroup("main");
         if (openLessonWarning
-            && settings.value("language_lesson", APP_STD_LANGUAGE_LESSON)
+            && settings.value("language_lesson", t10::app_std_language_lesson)
                     .toString()
                 == "en_us_qwerty") {
 
-            QMessageBox::information(this, APP_NAME,
+            QMessageBox::information(this, t10::app_name,
                 tr("At the moment open lessons only exists in German language. "
                    "We hope to provide open lessons in English soon."));
 
@@ -870,7 +873,7 @@ void StartWidget::clickTraining()
         // No selected lesson found in combo box
         // -> error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_SELECTED,
+        errorMessage->showMessage(Error::lessons_selected,
             ErrorMessage::Type::Info, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -897,7 +900,7 @@ void StartWidget::clickNewLesson()
         if (lessonSql->fillOwnList(listOwn, &arrayOwn) == -1) {
             // Error message
             ErrorMessage* errorMessage = new ErrorMessage(this);
-            errorMessage->showMessage(ERR_LESSONS_EXIST,
+            errorMessage->showMessage(Error::lessons_exist,
                 ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
             return;
         }
@@ -939,7 +942,7 @@ void StartWidget::clickImportLesson()
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_USER_IMPORT_READ,
+        errorMessage->showMessage(Error::user_import_read,
             ErrorMessage::Type::Info, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -960,7 +963,7 @@ void StartWidget::clickImportLesson()
     if (lessonData->size() < 2) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_USER_IMPORT_EMPTY,
+        errorMessage->showMessage(Error::user_import_empty,
             ErrorMessage::Type::Info, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -975,7 +978,7 @@ void StartWidget::clickImportLesson()
         if (lessonSql->fillOwnList(listOwn, &arrayOwn) == -1) {
             // Error message
             ErrorMessage* errorMessage = new ErrorMessage(this);
-            errorMessage->showMessage(ERR_LESSONS_EXIST,
+            errorMessage->showMessage(Error::lessons_exist,
                 ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
             return;
         }
@@ -1061,7 +1064,7 @@ void StartWidget::clickExportLesson()
     if (!file.open(QFile::WriteOnly | QIODevice::Text)) {
         // Error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_USER_EXPORT_WRITE,
+        errorMessage->showMessage(Error::user_export_write,
             ErrorMessage::Type::Info, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -1085,7 +1088,7 @@ void StartWidget::clickEditLesson()
         if (lessonSql->fillOwnList(listOwn, &arrayOwn) == -1) {
             // Error message
             ErrorMessage* errorMessage = new ErrorMessage(this);
-            errorMessage->showMessage(ERR_LESSONS_EXIST,
+            errorMessage->showMessage(Error::lessons_exist,
                 ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
             return;
         }
@@ -1096,7 +1099,7 @@ void StartWidget::clickEditLesson()
 
 void StartWidget::clickDeleteLesson()
 {
-    switch (QMessageBox::question(this, APP_NAME,
+    switch (QMessageBox::question(this, t10::app_name,
         tr("Do you really want to delete the lesson, and all the recorded data "
            "in the context of this lesson?"))) {
     case QMessageBox::Yes: {
@@ -1104,7 +1107,7 @@ void StartWidget::clickDeleteLesson()
         if (!lessonSql->deleteOwnLesson(arrayOwn.at(listOwn->currentRow()))) {
             // Error message
             ErrorMessage* errorMessage = new ErrorMessage(this);
-            errorMessage->showMessage(ERR_LESSONS_EXIST,
+            errorMessage->showMessage(Error::lessons_exist,
                 ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
             return;
         }
@@ -1112,7 +1115,7 @@ void StartWidget::clickDeleteLesson()
             // No selected lesson found in combo box
             // -> error message
             ErrorMessage* errorMessage = new ErrorMessage(this);
-            errorMessage->showMessage(ERR_USER_LESSON_ANALYZE,
+            errorMessage->showMessage(Error::user_lesson_analyze,
                 ErrorMessage::Type::Info, ErrorMessage::Cancel::Operation);
             return;
         }
@@ -1120,7 +1123,7 @@ void StartWidget::clickDeleteLesson()
         if (lessonSql->fillOwnList(listOwn, &arrayOwn) == -1) {
             // Error message
             ErrorMessage* errorMessage = new ErrorMessage(this);
-            errorMessage->showMessage(ERR_LESSONS_EXIST,
+            errorMessage->showMessage(Error::lessons_exist,
                 ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
             return;
         }
@@ -1196,9 +1199,9 @@ void StartWidget::readSettings()
     radioLimitToken->setChecked(settings.value("radio_token", false).toBool());
     spinLimitToken->setEnabled(settings.value("radio_token", false).toBool());
     spinLimitTime->setValue(
-        settings.value("spin_time", LESSON_TIMELEN_STANDARD).toInt());
+        settings.value("spin_time", t10::lesson_timelen_standard).toInt());
     spinLimitToken->setValue(
-        settings.value("spin_token", LESSON_TOKENLEN_STANDARD).toInt());
+        settings.value("spin_token", t10::lesson_tokenlen_standard).toInt());
     settings.endGroup();
     settings.beginGroup("error");
     checkErrorStop->setChecked(settings.value("check_stop", true).toBool());
