@@ -34,47 +34,40 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include <QVariant>
 
 #include "def/defines.h"
-#include "def/errordefines.h"
 #include "errormessage.h"
 #include "trainingwidget.h"
 
 TrainingWidget::TrainingWidget(
     int lesson, int type, QString name, QWidget* parent)
     : QWidget(parent)
+    , tickerBoard(new TickerBoard(this))
+    , currentChar(' ')
+    , currentLesson(lesson)
+    , currentType(type)
+    , currentName(name)
+    , currentStrokes(0)
+    , currentChars(0)
+    , currentErrors(0)
+    , currentSeconds(0)
+    , counterToNewLine(0)
+    , startTime(QDateTime::currentDateTime())
+    , isStarted(false)
+    , isPaused(false)
+    , errorCorrectFlag(false)
+    , oneErrorFlag(false)
+    , timer(new QTimer(this))
+    , metronomeTimer(new QTimer(this))
+    , companyLogo(new CompanyLogo(this, true))
 {
-    // Default values
-    isStarted = false;
-    isPaused = false;
-    currentChar = ' ';
-    currentStrokes = 0;
-    currentChars = 0;
-    currentErrors = 0;
-    currentSeconds = 0;
-    currentLesson = lesson;
-    currentType = type;
-    currentName = name;
-    errorCorrectFlag = false;
-    startTime = QDateTime::currentDateTime();
-    counterToNewLine = 0;
-    oneErrorFlag = false;
-
     // Init sound file
-    bells.setSource(QUrl::fromLocalFile(TIPP10_ROOTDIR + QString("error.wav")));
+    bells.setSource(
+        QUrl::fromLocalFile(t10::tipp10_datadir + QString("error.wav")));
     metronomeSound.setSource(
-        QUrl::fromLocalFile(TIPP10_ROOTDIR + QString("metronome.wav")));
-
-    // Initialise timer
-    timer = new QTimer(this);
-    metronomeTimer = new QTimer(this);
-
-    // Set the logo
-    companyLogo = new CompanyLogo(this, true);
+        QUrl::fromLocalFile(t10::tipp10_datadir + QString("metronome.wav")));
 
     // Create all type trainer objects
-    // 1. Ticker
-    tickerBoard = new TickerBoard(this);
-    // 2. Keyboard (set focus!)
-    if ((currentLesson % 100) >= NUMPAD_LESSON_START && currentType == 0) {
+    // 1. Keyboard (set focus!)
+    if ((currentLesson % 100) >= t10::numpad_lesson_start && currentType == 0) {
         numPad = new NumPad(this);
     } else {
         keyBoard = new KeyBoard(this);
@@ -82,7 +75,7 @@ TrainingWidget::TrainingWidget(
 
     readSettings();
 
-    // 3. Statusbar
+    // 2. Statusbar
     statusBar = new StatusBar(this);
     trainingSql = new TrainingSql(replaceSetting, regexpSetting, layoutSetting);
     // Create Buttons "Cancel" and "Pause"
@@ -97,16 +90,17 @@ TrainingWidget::TrainingWidget(
     // Create lesson text
     // createLesson();
     if (!showHelpers) {
-        if ((currentLesson % 100) >= NUMPAD_LESSON_START && currentType == 0) {
+        if ((currentLesson % 100) >= t10::numpad_lesson_start
+            && currentType == 0) {
             numPad->setVisible(false);
         } else {
             keyBoard->setVisible(false);
         }
         // statusBar->setVisible(false);
         // companyLogo->setVisible(false);
-        parent->setMinimumSize(APP_WIDTH_SMALL, APP_HEIGHT_SMALL);
+        parent->setMinimumSize(t10::app_width_small, t10::app_height_small);
         if (!parent->isMaximized()) {
-            parent->resize(APP_WIDTH_SMALL, APP_HEIGHT_SMALL);
+            parent->resize(t10::app_width_small, t10::app_height_small);
         }
     }
     tickerBoard->setFocus();
@@ -163,7 +157,7 @@ void TrainingWidget::createLayout()
     // Keyboard layout horizontal
     QHBoxLayout* keyboardLayout = new QHBoxLayout;
     keyboardLayout->addStretch(1);
-    if ((currentLesson % 100) >= NUMPAD_LESSON_START && currentType == 0) {
+    if ((currentLesson % 100) >= t10::numpad_lesson_start && currentType == 0) {
         keyboardLayout->addWidget(numPad);
     } else {
         keyboardLayout->addWidget(keyBoard);
@@ -190,37 +184,50 @@ void TrainingWidget::createLayout()
 
 void TrainingWidget::createConnections()
 {
-    connect(timer, SIGNAL(timeout()), this, SLOT(secondsUpdate()));
-    connect(metronomeTimer, SIGNAL(timeout()), this, SLOT(metronomeOutput()));
+    connect(timer, &QTimer::timeout, this, &TrainingWidget::secondsUpdate);
+    connect(metronomeTimer, &QTimer::timeout, this,
+        &TrainingWidget::metronomeOutput);
     // Incoming connections
     // Incoming connection from TickerBoard object
     connect(
-        tickerBoard, SIGNAL(charChanged(QChar)), this, SLOT(setChar(QChar)));
-    connect(tickerBoard, SIGNAL(updateRequired()), this, SLOT(updateLesson()));
+        tickerBoard, &TickerBoard::charChanged, this, &TrainingWidget::setChar);
+    connect(tickerBoard, &TickerBoard::updateRequired, this,
+        &TrainingWidget::updateLesson);
     // Incoming connection from KeyBoard object
-    connect(tickerBoard, SIGNAL(keyPressed(QChar)), this, SLOT(setKey(QChar)));
-    // connect(tickerBoard, SIGNAL(isReady()), this, SLOT(exitTraining()));
+    connect(
+        tickerBoard, &TickerBoard::keyPressed, this, &TrainingWidget::setKey);
+    // connect(tickerBoard, &TickerBoard::isReady, this,
+    // &TrainingWidget::exitTraining);
     // Button connections
-    connect(buttonPause, SIGNAL(clicked()), this, SLOT(pauseSession()));
-    connect(buttonPause, SIGNAL(clicked()), tickerBoard, SLOT(pauseTicker()));
-    connect(buttonCancel, SIGNAL(clicked()), this, SLOT(cancelSession()));
-    connect(buttonHelp, SIGNAL(clicked()), this, SLOT(pauseSession()));
-    connect(buttonHelp, SIGNAL(clicked()), tickerBoard, SLOT(pauseTicker()));
-    connect(buttonHelp, SIGNAL(clicked()), this, SLOT(showHelp()));
-    if ((currentLesson % 100) >= NUMPAD_LESSON_START && currentType == 0) {
+    connect(buttonPause, &QPushButton::clicked, this,
+        &TrainingWidget::pauseSession);
+    connect(buttonPause, &QPushButton::clicked, this,
+        [this]() { tickerBoard->pauseTicker(); });
+    connect(buttonCancel, &QPushButton::clicked, this,
+        &TrainingWidget::cancelSession);
+    connect(
+        buttonHelp, &QPushButton::clicked, this, &TrainingWidget::pauseSession);
+    connect(buttonHelp, &QPushButton::clicked, this,
+        [this]() { tickerBoard->pauseTicker(); });
+    connect(buttonHelp, &QPushButton::clicked, this, &TrainingWidget::showHelp);
+    if ((currentLesson % 100) >= t10::numpad_lesson_start && currentType == 0) {
         // Verbindung zwischen Laufschrift- und Tastaturklasse
-        connect(tickerBoard, SIGNAL(isReady()), numPad, SLOT(stopBoard()));
-        connect(numPad, SIGNAL(statusRefreshed(QString)), this,
-            SLOT(updateStatusText(QString)));
-        connect(buttonPause, SIGNAL(clicked()), numPad, SLOT(pauseBoard()));
-        connect(buttonHelp, SIGNAL(clicked()), numPad, SLOT(pauseBoard()));
+        connect(tickerBoard, &TickerBoard::isReady, numPad, &NumPad::stopBoard);
+        connect(numPad, &NumPad::statusRefreshed, this,
+            &TrainingWidget::updateStatusText);
+        connect(
+            buttonPause, &QPushButton::clicked, numPad, &NumPad::pauseBoard);
+        connect(buttonHelp, &QPushButton::clicked, numPad, &NumPad::pauseBoard);
     } else {
         // Verbindung zwischen Laufschrift- und Tastaturklasse
-        connect(tickerBoard, SIGNAL(isReady()), keyBoard, SLOT(stopBoard()));
-        connect(keyBoard, SIGNAL(statusRefreshed(QString)), this,
-            SLOT(updateStatusText(QString)));
-        connect(buttonPause, SIGNAL(clicked()), keyBoard, SLOT(pauseBoard()));
-        connect(buttonHelp, SIGNAL(clicked()), keyBoard, SLOT(pauseBoard()));
+        connect(
+            tickerBoard, &TickerBoard::isReady, keyBoard, &KeyBoard::stopBoard);
+        connect(keyBoard, &KeyBoard::statusRefreshed, this,
+            &TrainingWidget::updateStatusText);
+        connect(buttonPause, &QPushButton::clicked, keyBoard,
+            &KeyBoard::pauseBoard);
+        connect(
+            buttonHelp, &QPushButton::clicked, keyBoard, &KeyBoard::pauseBoard);
     }
 }
 
@@ -247,7 +254,7 @@ void TrainingWidget::cancelSession()
     // Ask only is lesson is started and if anything was typed at all
     if (isStarted && currentStrokes > 0) {
         // Ask if user wants to quit really
-        switch (QMessageBox::question(this, APP_NAME,
+        switch (QMessageBox::question(this, t10::app_name,
             tr("Do you really want to exit the lesson early?"))) {
         case QMessageBox::Yes:
             // User wants to quit
@@ -262,7 +269,7 @@ void TrainingWidget::cancelSession()
         }
         // Ask if user want to save data
         switch (QMessageBox::question(
-            this, APP_NAME, tr("Do you want to save your results?"))) {
+            this, t10::app_name, tr("Do you want to save your results?"))) {
         case QMessageBox::Yes:
             // Save and exit
             exitTraining();
@@ -291,7 +298,7 @@ void TrainingWidget::createLesson()
         // No lesson created
         // -> error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_CREATION,
+        errorMessage->showMessage(Error::lessons_creation,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         return;
     }
@@ -299,10 +306,10 @@ void TrainingWidget::createLesson()
     case 0:
         // Training lesson
         counterToNewLine = lessonString.length() + 1;
-        if ((currentLesson % 100) < BORDER_LESSON_IS_SENTENCE) {
+        if ((currentLesson % 100) < t10::border_lesson_is_sentence) {
             lessonString.append(" ");
         } else {
-            lessonString.append(QChar(TOKEN_NEW_LINE));
+            lessonString.append(t10::token_new_line);
         }
         break;
     case 1:
@@ -314,7 +321,7 @@ void TrainingWidget::createLesson()
             if (lessonUnit == 1) {
                 lessonString.append(" ");
             } else {
-                lessonString.append(QChar(TOKEN_NEW_LINE));
+                lessonString.append(t10::token_new_line);
             }
         } else {
             // Hole lesson
@@ -339,20 +346,21 @@ void TrainingWidget::updateLesson()
         // No update lesson created
         // -> error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_LESSONS_UPDATE,
+        errorMessage->showMessage(Error::lessons_update,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         return;
     }
     counterToNewLine += lessonString.length();
-    if ((currentType == 0 && (currentLesson % 100) < BORDER_LESSON_IS_SENTENCE
-            && counterToNewLine > NUM_TOKEN_UNTIL_NEW_LINE)
+    if ((currentType == 0
+            && (currentLesson % 100) < t10::border_lesson_is_sentence
+            && counterToNewLine > t10::num_token_until_new_line)
         || (currentType == 0
-            && (currentLesson % 100) >= BORDER_LESSON_IS_SENTENCE)
+            && (currentLesson % 100) >= t10::border_lesson_is_sentence)
         || (currentType != 0
             && (lessonUnit == 0
                 || (lessonUnit == 1
-                    && counterToNewLine > NUM_TOKEN_UNTIL_NEW_LINE)))) {
-        lessonString.append(QChar(TOKEN_NEW_LINE));
+                    && counterToNewLine > t10::num_token_until_new_line)))) {
+        lessonString.append(t10::token_new_line);
         counterToNewLine = 0;
     } else {
         counterToNewLine++;
@@ -367,14 +375,14 @@ void TrainingWidget::setChar(QChar newchar)
 {
     currentChars++;
     currentChar = newchar;
-    if ((currentLesson % 100) >= NUMPAD_LESSON_START && currentType == 0) {
+    if ((currentLesson % 100) >= t10::numpad_lesson_start && currentType == 0) {
         numPad->setKey(currentChar);
     } else {
         keyBoard->setKey(currentChar);
     }
     if (!trainingSql->updateUsertable(currentChar, "user_char_occur_num")) {
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_USER_ERRORS_REFRESH,
+        errorMessage->showMessage(Error::user_errors_refresh,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
     }
 }
@@ -387,7 +395,7 @@ void TrainingWidget::setKey(QChar key)
             // Ruecklauftaste
             if (key.unicode() == 8) {
                 errorCorrectFlag = false;
-                if ((currentLesson % 100) >= NUMPAD_LESSON_START
+                if ((currentLesson % 100) >= t10::numpad_lesson_start
                     && currentType == 0) {
                     numPad->setKey(currentChar);
                 } else {
@@ -402,8 +410,8 @@ void TrainingWidget::setKey(QChar key)
             // (char and unicode then are different)
             if (key == currentChar
                 || ((key.unicode() == 13 || key.unicode() == 3)
-                    && currentChar == QChar(TOKEN_NEW_LINE))
-                || (key.unicode() == 9 && currentChar == QChar(TOKEN_TAB))) {
+                    && currentChar == t10::token_new_line)
+                || (key.unicode() == 9 && currentChar == t10::token_tab)) {
                 // currentChar.unicode() == 182)) {
                 // Correct key was pressed
                 oneErrorFlag = false;
@@ -423,10 +431,10 @@ void TrainingWidget::setKey(QChar key)
                     update();
 
                     if (key.unicode() == 13 || key.unicode() == 3) {
-                        charList << QChar(TOKEN_NEW_LINE);
+                        charList << t10::token_new_line;
                     } else {
                         if (key.unicode() == 9) {
-                            charList << QChar(TOKEN_TAB);
+                            charList << t10::token_tab;
                         } else {
                             charList << key;
                         }
@@ -437,7 +445,7 @@ void TrainingWidget::setKey(QChar key)
                             currentChar, "user_char_target_errornum")) {
                         // Error message
                         ErrorMessage* errorMessage = new ErrorMessage(this);
-                        errorMessage->showMessage(ERR_USER_ERRORS_REFRESH,
+                        errorMessage->showMessage(Error::user_errors_refresh,
                             ErrorMessage::Type::Critical,
                             ErrorMessage::Cancel::Operation);
                     }
@@ -445,7 +453,7 @@ void TrainingWidget::setKey(QChar key)
                             key, "user_char_mistake_errornum")) {
                         // Error message
                         ErrorMessage* errorMessage = new ErrorMessage(this);
-                        errorMessage->showMessage(ERR_USER_ERRORS_REFRESH,
+                        errorMessage->showMessage(Error::user_errors_refresh,
                             ErrorMessage::Type::Critical,
                             ErrorMessage::Cancel::Operation);
                     }
@@ -459,11 +467,11 @@ void TrainingWidget::setKey(QChar key)
                 // statusBar->setCenterText(QString::number(key.unicode()));
                 if (correctOnError) {
                     errorCorrectFlag = true;
-                    if ((currentLesson % 100) >= NUMPAD_LESSON_START
+                    if ((currentLesson % 100) >= t10::numpad_lesson_start
                         && currentType == 0) {
-                        numPad->setKey(QChar(TOKEN_BACKSPACE));
+                        numPad->setKey(t10::token_backspace);
                     } else {
-                        keyBoard->setKey(QChar(TOKEN_BACKSPACE));
+                        keyBoard->setKey(t10::token_backspace);
                     }
                     // statusBar->setCenterText(tr("Kleiner Finger "
                     //	"rechts - Ruecklauftaste!"));
@@ -481,7 +489,7 @@ void TrainingWidget::setKey(QChar key)
             buttonCancel->setText(tr("E&xit Lesson early"));
             // Start board first, cause starting the ticker
             // emits a signal which need a started keyBoard
-            if ((currentLesson % 100) >= NUMPAD_LESSON_START
+            if ((currentLesson % 100) >= t10::numpad_lesson_start
                 && currentType == 0) {
                 numPad->startBoard();
             } else {
@@ -517,10 +525,10 @@ void TrainingWidget::metronomeOutput()
 void TrainingWidget::updateStatusValues()
 {
     // CPM
-    auto minutes = (double)currentSeconds / 60.0;
+    auto minutes = static_cast<double>(currentSeconds) / 60.0;
     double strokesPerMinute = 0.;
     if (minutes != 0) {
-        strokesPerMinute = ((double)currentStrokes / minutes);
+        strokesPerMinute = static_cast<double>(currentStrokes) / minutes;
     }
     // Time
     int timeMinutes = currentSeconds / 60;
@@ -533,7 +541,7 @@ void TrainingWidget::updateStatusValues()
     }
     statusBar->setLeftLeftText(tr("Errors: ") + QString::number(currentErrors));
     statusBar->setLeftText(
-        tr("Cpm: ") + QString::number((unsigned int)strokesPerMinute));
+        tr("Cpm: ") + QString::number(static_cast<uint32_t>(strokesPerMinute)));
     statusBar->setRightText(tr("Time: ") + time);
     statusBar->setRightRightText(
         tr("Characters: ") + QString::number(currentChars));
@@ -557,7 +565,7 @@ void TrainingWidget::exitTraining()
         // No lesson created
         // -> error message
         ErrorMessage* errorMessage = new ErrorMessage(this);
-        errorMessage->showMessage(ERR_USER_LESSONS_REFRESH,
+        errorMessage->showMessage(Error::user_lessons_refresh,
             ErrorMessage::Type::Critical, ErrorMessage::Cancel::Operation);
         lastRowId = 0;
     }
@@ -583,7 +591,7 @@ void TrainingWidget::readSettings()
     QSettings settings;
 #endif
     settings.beginGroup("main");
-    if (settings.value("language_layout", APP_STD_LANGUAGE_LAYOUT)
+    if (settings.value("language_layout", t10::app_std_language_layout)
             .toString()
             .right(3)
         == "win") {
@@ -592,21 +600,22 @@ void TrainingWidget::readSettings()
         opSystem = "mac";
     }
     useEszett = true;
-    if (settings.value("language_layout", APP_STD_LANGUAGE_LAYOUT)
+    if (settings.value("language_layout", t10::app_std_language_layout)
             .toString()
             .left(2)
         == "ch") {
         useEszett = false;
     }
     useUmlaut = true;
-    if (settings.value("language_layout", APP_STD_LANGUAGE_LAYOUT)
+    if (settings.value("language_layout", t10::app_std_language_layout)
             .toString()
             .left(2)
         == "us") {
         useUmlaut = false;
     }
     layoutSetting
-        = settings.value("language_layout", APP_STD_LANGUAGE_LAYOUT).toString();
+        = settings.value("language_layout", t10::app_std_language_layout)
+              .toString();
     replaceSetting = settings.value("layout_replace", "NULL").toString();
     regexpSetting = settings.value("layout_regexp", "NULL").toString();
 
@@ -617,13 +626,14 @@ void TrainingWidget::readSettings()
         // Time limit selected
         limitType = 0;
         limitValue
-            = settings.value("spin_time", LESSON_TIMELEN_STANDARD).toInt();
+            = settings.value("spin_time", t10::lesson_timelen_standard).toInt();
     } else {
         if (settings.value("radio_token", true).toBool()) {
             // Token limit selected
             limitType = 1;
-            limitValue = settings.value("spin_token", LESSON_TOKENLEN_STANDARD)
-                             .toInt();
+            limitValue
+                = settings.value("spin_token", t10::lesson_tokenlen_standard)
+                      .toInt();
         } else {
             // Lesson limit selected
             limitType = 2;
@@ -641,12 +651,10 @@ void TrainingWidget::readSettings()
     showStatusInformation = settings.value("check_status", true).toBool();
     settings.endGroup();
     settings.beginGroup("sound");
-    metronomeClock
-        = settings.value("spin_metronome", METRONOM_STANDARD).toInt();
-    metronomeClock = (int)((double)metronomeClock * 60000.0)
-        / ((double)metronomeClock * (double)metronomeClock);
-    if (!settings.value("check_metronome", false).toBool()) {
-        metronomeClock = 0;
+    if (settings.value("check_metronome", false).toBool()) {
+        metronomeClock
+            = settings.value("spin_metronome", t10::metronom_standard).toInt();
+        metronomeClock = 60000 / metronomeClock;
     }
     settings.endGroup();
 
